@@ -1,7 +1,7 @@
 /****************************************************************************
 **
-** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
-** Contact: http://www.qt-project.org/legal
+** Copyright (C) 2015 The Qt Company Ltd.
+** Contact: http://www.qt.io/licensing/
 **
 ** This file is part of the examples of the Qt Toolkit.
 **
@@ -17,8 +17,8 @@
 **     notice, this list of conditions and the following disclaimer in
 **     the documentation and/or other materials provided with the
 **     distribution.
-**   * Neither the name of Digia Plc and its Subsidiary(-ies) nor the names
-**     of its contributors may be used to endorse or promote products derived
+**   * Neither the name of The Qt Company Ltd nor the names of its
+**     contributors may be used to endorse or promote products derived
 **     from this software without specific prior written permission.
 **
 **
@@ -46,18 +46,19 @@
 
 MultiPageWidget::MultiPageWidget(QWidget *parent)
     : QWidget(parent)
+    , stackWidget(new QStackedWidget)
+    , comboBox(new QComboBox)
 {
-    comboBox = new QComboBox();
+    typedef void (QComboBox::*ComboBoxActivatedIntSignal)(int);
+
     comboBox->setObjectName("__qt__passive_comboBox");
-    stackWidget = new QStackedWidget();
 
-    connect(comboBox, SIGNAL(activated(int)),
-            this, SLOT(setCurrentIndex(int)));
+    connect(comboBox, static_cast<ComboBoxActivatedIntSignal>(&QComboBox::activated),
+            this, &MultiPageWidget::setCurrentIndex);
 
-    layout = new QVBoxLayout();
+    QVBoxLayout *layout = new QVBoxLayout(this);
     layout->addWidget(comboBox);
     layout->addWidget(stackWidget);
-    setLayout(layout);
 }
 
 QSize MultiPageWidget::sizeHint() const
@@ -99,6 +100,8 @@ void MultiPageWidget::insertPage(int index, QWidget *page)
         title = tr("Page %1").arg(comboBox->count() + 1);
         page->setWindowTitle(title);
     }
+    connect(page, &QWidget::windowTitleChanged,
+            this, &MultiPageWidget::pageWindowTitleChanged);
     comboBox->insertItem(index, title);
 }
 
@@ -111,6 +114,13 @@ void MultiPageWidget::setCurrentIndex(int index)
     }
 }
 
+void MultiPageWidget::pageWindowTitleChanged()
+{
+    QWidget *page = qobject_cast<QWidget *>(sender());
+    const int index = stackWidget->indexOf(page);
+    comboBox->setItemText(index, page->windowTitle());
+}
+
 QWidget* MultiPageWidget::widget(int index)
 {
     return stackWidget->widget(index);
@@ -125,7 +135,6 @@ QString MultiPageWidget::pageTitle() const
 
 void MultiPageWidget::setPageTitle(QString const &newTitle)
 {
-    comboBox->setItemText(currentIndex(), newTitle);
     if (QWidget *currentWidget = stackWidget->currentWidget())
         currentWidget->setWindowTitle(newTitle);
     emit pageTitleChanged(newTitle);
