@@ -4,7 +4,7 @@
 * Distributable under the terms of either the Apache License (Version 2.0) or 
 * the GNU Lesser General Public License, as specified in the COPYING file.
 *
-* Changes are Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
+* Changes are Copyright (C) 2015 The Qt Company Ltd.
 ------------------------------------------------------------------------------*/
 #include "CLucene/StdHeader.h"
 #include "CLucene/util/Misc.h"
@@ -24,8 +24,10 @@
 
 CL_NS_USE(util)
 
-TCHAR* _LUCENE_BLANK_STRING = _T("");
-char* _LUCENE_BLANK_ASTRING = "";
+const TCHAR *_CONST_LUCENE_BLANK_STRING = _T("");
+const char *_CONST_LUCENE_BLANK_ASTRING = "";
+TCHAR* _LUCENE_BLANK_STRING = const_cast<TCHAR *>(_CONST_LUCENE_BLANK_STRING);
+char* _LUCENE_BLANK_ASTRING = const_cast<char *>(_CONST_LUCENE_BLANK_ASTRING);
 
 #ifndef Q_CC_MIPS
 #if defined(_LUCENE_THREADMUTEX_USINGDEFAULT)
