@@ -4,7 +4,7 @@
 * Distributable under the terms of either the Apache License (Version 2.0) or
 * the GNU Lesser General Public License, as specified in the COPYING file.
 *
-* Changes are Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
+* Changes are Copyright (C) 2015 The Qt Company Ltd.
 ------------------------------------------------------------------------------*/
 #ifndef lucene_stdheader_h
 #define lucene_stdheader_h
@@ -122,7 +122,10 @@ extern int _lucene_counter_break; //can set a watch on this
  #error "CLucene can't compile without the vector header"
 #endif
 
-#if !defined(LUCENE_DISABLE_HASHING) && defined(_CL_HAVE_HASH_MAP) && defined(_CL_HAVE_HASH_SET)
+#if !defined(LUCENE_DISABLE_HASHING) && defined(_CL_HAVE_STD_UNORDERED_MAP) && defined(_CL_HAVE_STD_UNORDERED_SET)
+    #include <unordered_map>
+    #include <unordered_set>
+#elif !defined(LUCENE_DISABLE_HASHING) && defined(_CL_HAVE_HASH_MAP) && defined(_CL_HAVE_HASH_SET)
 	//hashing is all or nothing!
 	#include <hash_map>
 	#include <hash_set>
