@@ -1,7 +1,7 @@
 /****************************************************************************
 **
-** Copyright (C) 2014 Digia Plc and/or its subsidiary(-ies).
-** Contact: http://www.qt-project.org/legal
+** Copyright (C) 2015 The Qt Company Ltd.
+** Contact: http://www.qt.io/licensing/
 **
 ** This file is part of the Qt Assistant of the Qt Toolkit.
 **
@@ -10,9 +10,9 @@
 ** Licensees holding valid commercial Qt licenses may use this file in
 ** accordance with the commercial license agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and Digia. For licensing terms and
-** conditions see http://qt.digia.com/licensing. For further information
-** use the contact form at http://qt.digia.com/contact-us.
+** a written agreement between you and The Qt Company. For licensing terms
+** and conditions see http://www.qt.io/terms-conditions. For further
+** information use the contact form at http://www.qt.io/contact-us.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -23,8 +23,8 @@
 ** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
 ** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** In addition, as a special exception, Digia gives you certain additional
-** rights. These rights are described in the Digia Qt LGPL Exception
+** As a special exception, The Qt Company gives you certain additional
+** rights. These rights are described in The Qt Company LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
 ** $QT_END_LICENSE$
@@ -42,19 +42,19 @@
 #include <QtWidgets/QAction>
 #include <QtGui/QFont>
 
-#if defined(QT_NO_WEBKIT)
-#include <QtWidgets/QTextBrowser>
-#else
-#include <QWebView>
+#if defined(BROWSER_QTWEBKIT)
+#  include <QWebView>
+#elif defined(BROWSER_QTEXTBROWSER)
+#  include <QtWidgets/QTextBrowser>
 #endif
 
 QT_BEGIN_NAMESPACE
 
 class HelpEngineWrapper;
 
-#if !defined(QT_NO_WEBKIT)
+#if defined(BROWSER_QTWEBKIT)
 class HelpViewer : public QWebView
-#else
+#elif defined(BROWSER_QTEXTBROWSER)
 class HelpViewer : public QTextBrowser
 #endif
 {
@@ -114,14 +114,16 @@ public slots:
 
 signals:
     void titleChanged();
-#if !defined(QT_NO_WEBKIT)
+#if !defined(BROWSER_QTEXTBROWSER)
+    // Provide signals present in QTextBrowser, QTextEdit for browsers that do not inherit QTextBrowser
     void copyAvailable(bool yes);
     void sourceChanged(const QUrl &url);
     void forwardAvailable(bool enabled);
     void backwardAvailable(bool enabled);
     void highlighted(const QString &link);
     void printRequested();
-#else
+#elif !defined(BROWSER_QTWEBKIT)
+    // Provide signals present in QWebView for browsers that do not inherit QWebView
     void loadStarted();
     void loadFinished(bool finished);
 #endif
