@@ -1,7 +1,7 @@
 /****************************************************************************
 **
-** Copyright (C) 2014 Digia Plc and/or its subsidiary(-ies).
-** Contact: http://www.qt-project.org/legal
+** Copyright (C) 2015 The Qt Company Ltd.
+** Contact: http://www.qt.io/licensing/
 **
 ** This file is part of the Qt Designer of the Qt Toolkit.
 **
@@ -10,9 +10,9 @@
 ** Licensees holding valid commercial Qt licenses may use this file in
 ** accordance with the commercial license agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and Digia. For licensing terms and
-** conditions see http://qt.digia.com/licensing. For further information
-** use the contact form at http://qt.digia.com/contact-us.
+** a written agreement between you and The Qt Company. For licensing terms
+** and conditions see http://www.qt.io/terms-conditions. For further
+** information use the contact form at http://www.qt.io/contact-us.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -23,8 +23,8 @@
 ** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
 ** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** In addition, as a special exception, Digia gives you certain additional
-** rights. These rights are described in the Digia Qt LGPL Exception
+** As a special exception, The Qt Company gives you certain additional
+** rights. These rights are described in The Qt Company LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
 ** $QT_END_LICENSE$
@@ -54,7 +54,7 @@ protected:
     explicit ActionProviderBase(QWidget *widget);
 
 public:
-    virtual void adjustIndicator(const QPoint &pos);
+    void adjustIndicator(const QPoint &pos) Q_DECL_OVERRIDE;
     virtual Qt::Orientation orientation() const = 0;
 
 protected:
@@ -71,12 +71,12 @@ class QT_FORMEDITOR_EXPORT QToolBarActionProvider: public QObject, public Action
 public:
     explicit QToolBarActionProvider(QToolBar *widget, QObject *parent = 0);
 
-    virtual QRect actionGeometry(QAction *action) const;
-    virtual QAction *actionAt(const QPoint &pos) const;
+    QRect actionGeometry(QAction *action) const Q_DECL_OVERRIDE;
+    QAction *actionAt(const QPoint &pos) const Q_DECL_OVERRIDE;
     Qt::Orientation orientation() const;
 
 protected:
-    virtual QRect indicatorGeometry(const QPoint &pos, Qt::LayoutDirection layoutDirection) const;
+    QRect indicatorGeometry(const QPoint &pos, Qt::LayoutDirection layoutDirection) const Q_DECL_OVERRIDE;
 
 private:
     QToolBar *m_widget;
@@ -89,8 +89,8 @@ class QT_FORMEDITOR_EXPORT QMenuBarActionProvider: public QObject, public Action
 public:
     explicit QMenuBarActionProvider(QMenuBar *widget, QObject *parent = 0);
 
-    virtual QRect actionGeometry(QAction *action) const;
-    virtual QAction *actionAt(const QPoint &pos) const;
+    QRect actionGeometry(QAction *action) const Q_DECL_OVERRIDE;
+    QAction *actionAt(const QPoint &pos) const Q_DECL_OVERRIDE;
     Qt::Orientation orientation() const;
 
 private:
@@ -104,8 +104,8 @@ class QT_FORMEDITOR_EXPORT QMenuActionProvider: public QObject, public ActionPro
 public:
     explicit QMenuActionProvider(QMenu *widget, QObject *parent = 0);
 
-    virtual QRect actionGeometry(QAction *action) const;
-    virtual QAction *actionAt(const QPoint &pos) const;
+    QRect actionGeometry(QAction *action) const Q_DECL_OVERRIDE;
+    QAction *actionAt(const QPoint &pos) const Q_DECL_OVERRIDE;
     Qt::Orientation orientation() const;
 
 private:
