@@ -1,40 +1,32 @@
 /****************************************************************************
 **
-** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
-** Contact: http://www.qt-project.org/legal
+** Copyright (C) 2015 The Qt Company Ltd.
+** Contact: http://www.qt.io/licensing/
 **
 ** This file is part of the Qt Designer of the Qt Toolkit.
 **
-** $QT_BEGIN_LICENSE:LGPL$
+** $QT_BEGIN_LICENSE:LGPL21$
 ** Commercial License Usage
 ** Licensees holding valid commercial Qt licenses may use this file in
 ** accordance with the commercial license agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and Digia.  For licensing terms and
-** conditions see http://qt.digia.com/licensing.  For further information
-** use the contact form at http://qt.digia.com/contact-us.
+** a written agreement between you and The Qt Company. For licensing terms
+** and conditions see http://www.qt.io/terms-conditions. For further
+** information use the contact form at http://www.qt.io/contact-us.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 2.1 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU Lesser General Public License version 2.1 requirements
-** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+** General Public License version 2.1 or version 3 as published by the Free
+** Software Foundation and appearing in the file LICENSE.LGPLv21 and
+** LICENSE.LGPLv3 included in the packaging of this file. Please review the
+** following information to ensure the GNU Lesser General Public License
+** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
+** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** In addition, as a special exception, Digia gives you certain additional
-** rights.  These rights are described in the Digia Qt LGPL Exception
+** As a special exception, The Qt Company gives you certain additional
+** rights. These rights are described in The Qt Company LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
-**
-**
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -68,11 +60,11 @@ public:
     virtual QWidget *widget(int index) const { return m_widget->widget(index); }
 
     virtual int currentIndex() const { return m_widget->currentIndex(); }
-    virtual void setCurrentIndex(int index);
+    void setCurrentIndex(int index) Q_DECL_OVERRIDE;
 
-    virtual void addWidget(QWidget *widget);
-    virtual void insertWidget(int index, QWidget *widget);
-    virtual void remove(int index);
+    void addWidget(QWidget *widget) Q_DECL_OVERRIDE;
+    void insertWidget(int index, QWidget *widget) Q_DECL_OVERRIDE;
+    void remove(int index) Q_DECL_OVERRIDE;
 
 private:
     QStackedWidget *m_widget;
@@ -90,11 +82,11 @@ public:
     virtual QWidget *widget(int index) const { return m_widget->widget(index); }
 
     virtual int currentIndex() const { return m_widget->currentIndex(); }
-    virtual void setCurrentIndex(int index);
+    void setCurrentIndex(int index) Q_DECL_OVERRIDE;
 
-    virtual void addWidget(QWidget *widget);
-    virtual void insertWidget(int index, QWidget *widget);
-    virtual void remove(int index);
+    void addWidget(QWidget *widget) Q_DECL_OVERRIDE;
+    void insertWidget(int index, QWidget *widget) Q_DECL_OVERRIDE;
+    void remove(int index) Q_DECL_OVERRIDE;
 
 private:
     QTabWidget *m_widget;
@@ -112,11 +104,11 @@ public:
     virtual QWidget *widget(int index) const { return m_widget->widget(index); }
 
     virtual int currentIndex() const { return m_widget->currentIndex(); }
-    virtual void setCurrentIndex(int index);
+    void setCurrentIndex(int index) Q_DECL_OVERRIDE;
 
-    virtual void addWidget(QWidget *widget);
-    virtual void insertWidget(int index, QWidget *widget);
-    virtual void remove(int index);
+    void addWidget(QWidget *widget) Q_DECL_OVERRIDE;
+    void insertWidget(int index, QWidget *widget) Q_DECL_OVERRIDE;
+    void remove(int index) Q_DECL_OVERRIDE;
 
 private:
     QToolBox *m_widget;
@@ -131,12 +123,12 @@ class SingleChildContainer: public QDesignerContainerExtension
 protected:
     explicit SingleChildContainer(Container *widget, bool active = true);
 public:
-    virtual int count() const;
-    virtual QWidget *widget(int index) const;
-    virtual int currentIndex() const;
+    int count() const Q_DECL_OVERRIDE;
+    QWidget *widget(int index) const Q_DECL_OVERRIDE;
+    int currentIndex() const Q_DECL_OVERRIDE;
     virtual void setCurrentIndex(int /*index*/) {}
-    virtual void addWidget(QWidget *widget);
-    virtual void insertWidget(int index, QWidget *widget);
+    void addWidget(QWidget *widget) Q_DECL_OVERRIDE;
+    void insertWidget(int index, QWidget *widget) Q_DECL_OVERRIDE;
     virtual void remove(int /*index*/) {}
 
     virtual bool canAddWidget() const { return false; }
