@@ -1,7 +1,7 @@
 /****************************************************************************
 **
-** Copyright (C) 2014 Digia Plc and/or its subsidiary(-ies).
-** Contact: http://www.qt-project.org/legal
+** Copyright (C) 2015 The Qt Company Ltd.
+** Contact: http://www.qt.io/licensing/
 **
 ** This file is part of the Qt Designer of the Qt Toolkit.
 **
@@ -10,9 +10,9 @@
 ** Licensees holding valid commercial Qt licenses may use this file in
 ** accordance with the commercial license agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and Digia. For licensing terms and
-** conditions see http://qt.digia.com/licensing. For further information
-** use the contact form at http://qt.digia.com/contact-us.
+** a written agreement between you and The Qt Company. For licensing terms
+** and conditions see http://www.qt.io/terms-conditions. For further
+** information use the contact form at http://www.qt.io/contact-us.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -23,8 +23,8 @@
 ** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
 ** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** In addition, as a special exception, Digia gives you certain additional
-** rights. These rights are described in the Digia Qt LGPL Exception
+** As a special exception, The Qt Company gives you certain additional
+** rights. These rights are described in The Qt Company LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
 ** $QT_END_LICENSE$
@@ -135,13 +135,13 @@ public:
     QStringList loadedQrcFiles() const                    { return m_loadedQrcFiles.keys(); } // needed only for loading old resource attribute of <iconset> tag.
 #endif
 
-    virtual QVariant loadResource(const QDir &workingDirectory, const DomProperty *icon) const;
+    QVariant loadResource(const QDir &workingDirectory, const DomProperty *icon) const Q_DECL_OVERRIDE;
 
-    virtual QVariant toNativeValue(const QVariant &value) const;
+    QVariant toNativeValue(const QVariant &value) const Q_DECL_OVERRIDE;
 
-    virtual DomProperty *saveResource(const QDir &workingDirectory, const QVariant &value) const;
+    DomProperty *saveResource(const QDir &workingDirectory, const QVariant &value) const Q_DECL_OVERRIDE;
 
-    virtual bool isResourceType(const QVariant &value) const;
+    bool isResourceType(const QVariant &value) const Q_DECL_OVERRIDE;
 private:
 
     QDesignerFormEditorInterface *m_core;
@@ -364,11 +364,11 @@ class QDesignerTextBuilder : public QTextBuilder
 public:
     QDesignerTextBuilder() {}
 
-    virtual QVariant loadText(const DomProperty *icon) const;
+    QVariant loadText(const DomProperty *icon) const Q_DECL_OVERRIDE;
 
-    virtual QVariant toNativeValue(const QVariant &value) const;
+    QVariant toNativeValue(const QVariant &value) const Q_DECL_OVERRIDE;
 
-    virtual DomProperty *saveText(const QVariant &value) const;
+    DomProperty *saveText(const QVariant &value) const Q_DECL_OVERRIDE;
 };
 
 QVariant QDesignerTextBuilder::loadText(const DomProperty *text) const
