@@ -1,7 +1,7 @@
 /****************************************************************************
 **
-** Copyright (C) 2014 Digia Plc and/or its subsidiary(-ies).
-** Contact: http://www.qt-project.org/legal
+** Copyright (C) 2015 The Qt Company Ltd.
+** Contact: http://www.qt.io/licensing/
 **
 ** This file is part of the Qt Designer of the Qt Toolkit.
 **
@@ -10,9 +10,9 @@
 ** Licensees holding valid commercial Qt licenses may use this file in
 ** accordance with the commercial license agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and Digia. For licensing terms and
-** conditions see http://qt.digia.com/licensing. For further information
-** use the contact form at http://qt.digia.com/contact-us.
+** a written agreement between you and The Qt Company. For licensing terms
+** and conditions see http://www.qt.io/terms-conditions. For further
+** information use the contact form at http://www.qt.io/contact-us.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -23,8 +23,8 @@
 ** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
 ** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** In addition, as a special exception, Digia gives you certain additional
-** rights. These rights are described in the Digia Qt LGPL Exception
+** As a special exception, The Qt Company gives you certain additional
+** rights. These rights are described in The Qt Company LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
 ** $QT_END_LICENSE$
@@ -78,7 +78,8 @@ unsigned ActionData::compare(const ActionData &rhs) const
 NewActionDialog::NewActionDialog(ActionEditor *parent) :
     QDialog(parent, Qt::Sheet),
     m_ui(new Ui::NewActionDialog),
-    m_actionEditor(parent)
+    m_actionEditor(parent),
+    m_autoUpdateObjectName(true)
 {
     m_ui->setupUi(this);
 
@@ -90,7 +91,6 @@ NewActionDialog::NewActionDialog(ActionEditor *parent) :
 
     setWindowFlags(windowFlags() & ~Qt::WindowContextHelpButtonHint);
     m_ui->editActionText->setFocus();
-    m_auto_update_object_name = true;
     updateButtons();
 
     QDesignerFormWindowInterface *form = parent->formWindow();
@@ -141,16 +141,14 @@ void NewActionDialog::setActionData(const ActionData &d)
     m_ui->keySequenceEdit->setKeySequence(d.keysequence.value());
     m_ui->checkableCheckBox->setCheckState(d.checkable ? Qt::Checked : Qt::Unchecked);
 
-    m_auto_update_object_name = false;
+    // Suppress updating of the object name from the text for existing actions.
+    m_autoUpdateObjectName = d.name.isEmpty();
     updateButtons();
 }
 
 void NewActionDialog::on_editActionText_textEdited(const QString &text)
 {
-    if (text.isEmpty())
-        m_auto_update_object_name = true;
-
-    if (m_auto_update_object_name)
+    if (m_autoUpdateObjectName)
         m_ui->editObjectName->setText(ActionEditor::actionTextToName(text));
 
     updateButtons();
@@ -159,7 +157,7 @@ void NewActionDialog::on_editActionText_textEdited(const QString &text)
 void NewActionDialog::on_editObjectName_textEdited(const QString&)
 {
     updateButtons();
-    m_auto_update_object_name = false;
+    m_autoUpdateObjectName = false;
 }
 
 void NewActionDialog::slotEditToolTip()
