@@ -1,40 +1,32 @@
 /****************************************************************************
 **
-** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
-** Contact: http://www.qt-project.org/legal
+** Copyright (C) 2015 The Qt Company Ltd.
+** Contact: http://www.qt.io/licensing/
 **
 ** This file is part of the Qt Designer of the Qt Toolkit.
 **
-** $QT_BEGIN_LICENSE:LGPL$
+** $QT_BEGIN_LICENSE:LGPL21$
 ** Commercial License Usage
 ** Licensees holding valid commercial Qt licenses may use this file in
 ** accordance with the commercial license agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and Digia.  For licensing terms and
-** conditions see http://qt.digia.com/licensing.  For further information
-** use the contact form at http://qt.digia.com/contact-us.
+** a written agreement between you and The Qt Company. For licensing terms
+** and conditions see http://www.qt.io/terms-conditions. For further
+** information use the contact form at http://www.qt.io/contact-us.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 2.1 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU Lesser General Public License version 2.1 requirements
-** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+** General Public License version 2.1 or version 3 as published by the Free
+** Software Foundation and appearing in the file LICENSE.LGPLv21 and
+** LICENSE.LGPLv3 included in the packaging of this file. Please review the
+** following information to ensure the GNU Lesser General Public License
+** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
+** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** In addition, as a special exception, Digia gives you certain additional
-** rights.  These rights are described in the Digia Qt LGPL Exception
+** As a special exception, The Qt Company gives you certain additional
+** rights. These rights are described in The Qt Company LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
-**
-**
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -426,7 +418,7 @@ int LayoutProperties::toPropertySheet(const QDesignerFormEditorInterface *core,
                 rc |= spacingFlags[i];
     // sizeConstraint
     variantPropertyToSheet(mask, SizeConstraintProperty, applyChanged, sheet, QLatin1String(sizeConstraintC), m_sizeConstraint, m_sizeConstraintChanged, &rc);
-    variantPropertyToSheet(mask, FieldGrowthPolicyProperty, applyChanged, sheet, QLatin1String(fieldGrowthPolicyPropertyC), m_fieldGrowthPolicy, &m_fieldGrowthPolicyChanged, &rc);
+    variantPropertyToSheet(mask, FieldGrowthPolicyProperty, applyChanged, sheet, QLatin1String(fieldGrowthPolicyPropertyC), m_fieldGrowthPolicy, m_fieldGrowthPolicyChanged, &rc);
     variantPropertyToSheet(mask, RowWrapPolicyProperty, applyChanged, sheet, QLatin1String(rowWrapPolicyPropertyC), m_rowWrapPolicy, m_rowWrapPolicyChanged, &rc);
     variantPropertyToSheet(mask, LabelAlignmentProperty, applyChanged, sheet, QLatin1String(labelAlignmentPropertyC), m_labelAlignment, m_labelAlignmentChanged, &rc);
     variantPropertyToSheet(mask, FormAlignmentProperty, applyChanged, sheet, QLatin1String(formAlignmentPropertyC), m_formAlignment, m_formAlignmentChanged, &rc);
@@ -474,13 +466,13 @@ QRect LayoutHelper::itemInfo(QLayout *lt, const QWidget *widget) const
     public:
         BoxLayoutHelper(const Qt::Orientation orientation) : m_orientation(orientation) {}
 
-        virtual QRect itemInfo(QLayout *lt, int index) const;
-        virtual void insertWidget(QLayout *lt, const QRect &info, QWidget *w);
-        virtual void removeWidget(QLayout *lt, QWidget *widget);
-        virtual void replaceWidget(QLayout *lt, QWidget *before, QWidget *after);
+        QRect itemInfo(QLayout *lt, int index) const Q_DECL_OVERRIDE;
+        void insertWidget(QLayout *lt, const QRect &info, QWidget *w) Q_DECL_OVERRIDE;
+        void removeWidget(QLayout *lt, QWidget *widget) Q_DECL_OVERRIDE;
+        void replaceWidget(QLayout *lt, QWidget *before, QWidget *after) Q_DECL_OVERRIDE;
 
-        virtual void pushState(const QDesignerFormEditorInterface *, const QWidget *);
-        virtual void popState(const QDesignerFormEditorInterface *, QWidget *);
+        void pushState(const QDesignerFormEditorInterface *, const QWidget *) Q_DECL_OVERRIDE;
+        void popState(const QDesignerFormEditorInterface *, QWidget *) Q_DECL_OVERRIDE;
 
         virtual bool canSimplify(const QDesignerFormEditorInterface *, const QWidget *, const QRect &) const { return  false; }
         virtual void simplify(const QDesignerFormEditorInterface *, QWidget *, const QRect &) {}
@@ -894,16 +886,16 @@ QRect LayoutHelper::itemInfo(QLayout *lt, const QWidget *widget) const
     public:
         GridLayoutHelper() {}
 
-        virtual QRect itemInfo(QLayout *lt, int index) const;
-        virtual void insertWidget(QLayout *lt, const QRect &info, QWidget *w);
-        virtual void removeWidget(QLayout *lt, QWidget *widget);
-        virtual void replaceWidget(QLayout *lt, QWidget *before, QWidget *after);
+        QRect itemInfo(QLayout *lt, int index) const Q_DECL_OVERRIDE;
+        void insertWidget(QLayout *lt, const QRect &info, QWidget *w) Q_DECL_OVERRIDE;
+        void removeWidget(QLayout *lt, QWidget *widget) Q_DECL_OVERRIDE;
+        void replaceWidget(QLayout *lt, QWidget *before, QWidget *after) Q_DECL_OVERRIDE;
 
-        virtual void pushState(const QDesignerFormEditorInterface *core, const QWidget *widgetWithManagedLayout);
-        virtual void popState(const QDesignerFormEditorInterface *core, QWidget *widgetWithManagedLayout);
+        void pushState(const QDesignerFormEditorInterface *core, const QWidget *widgetWithManagedLayout) Q_DECL_OVERRIDE;
+        void popState(const QDesignerFormEditorInterface *core, QWidget *widgetWithManagedLayout) Q_DECL_OVERRIDE;
 
-        virtual bool canSimplify(const QDesignerFormEditorInterface *core, const QWidget *widgetWithManagedLayout, const QRect &restrictionArea) const;
-        virtual void simplify(const QDesignerFormEditorInterface *core, QWidget *widgetWithManagedLayout, const QRect &restrictionArea);
+        bool canSimplify(const QDesignerFormEditorInterface *core, const QWidget *widgetWithManagedLayout, const QRect &restrictionArea) const Q_DECL_OVERRIDE;
+        void simplify(const QDesignerFormEditorInterface *core, QWidget *widgetWithManagedLayout, const QRect &restrictionArea) Q_DECL_OVERRIDE;
 
         static void insertRow(QGridLayout *grid, int row);
 
@@ -1051,16 +1043,16 @@ QRect LayoutHelper::itemInfo(QLayout *lt, const QWidget *widget) const
 
         FormLayoutHelper() {}
 
-        virtual QRect itemInfo(QLayout *lt, int index) const;
-        virtual void insertWidget(QLayout *lt, const QRect &info, QWidget *w);
-        virtual void removeWidget(QLayout *lt, QWidget *widget);
-        virtual void replaceWidget(QLayout *lt, QWidget *before, QWidget *after);
+        QRect itemInfo(QLayout *lt, int index) const Q_DECL_OVERRIDE;
+        void insertWidget(QLayout *lt, const QRect &info, QWidget *w) Q_DECL_OVERRIDE;
+        void removeWidget(QLayout *lt, QWidget *widget) Q_DECL_OVERRIDE;
+        void replaceWidget(QLayout *lt, QWidget *before, QWidget *after) Q_DECL_OVERRIDE;
 
-        virtual void pushState(const QDesignerFormEditorInterface *core, const QWidget *widgetWithManagedLayout);
-        virtual void popState(const QDesignerFormEditorInterface *core, QWidget *widgetWithManagedLayout);
+        void pushState(const QDesignerFormEditorInterface *core, const QWidget *widgetWithManagedLayout) Q_DECL_OVERRIDE;
+        void popState(const QDesignerFormEditorInterface *core, QWidget *widgetWithManagedLayout) Q_DECL_OVERRIDE;
 
-        virtual bool canSimplify(const QDesignerFormEditorInterface *core, const QWidget *, const QRect &) const;
-        virtual void simplify(const QDesignerFormEditorInterface *, QWidget *, const QRect &);
+        bool canSimplify(const QDesignerFormEditorInterface *core, const QWidget *, const QRect &) const Q_DECL_OVERRIDE;
+        void simplify(const QDesignerFormEditorInterface *, QWidget *, const QRect &) Q_DECL_OVERRIDE;
 
     private:
         static FormLayoutState state(const QFormLayout *lt);
@@ -1573,8 +1565,8 @@ class QBoxLayoutSupport: public QLayoutSupport
 public:
     QBoxLayoutSupport(QDesignerFormWindowInterface *formWindow, QWidget *widget, Qt::Orientation orientation, QObject *parent = 0);
 
-    virtual void insertWidget(QWidget *widget, const QPair<int, int> &cell);
-    virtual void removeWidget(QWidget *widget);
+    void insertWidget(QWidget *widget, const QPair<int, int> &cell) Q_DECL_OVERRIDE;
+    void removeWidget(QWidget *widget) Q_DECL_OVERRIDE;
     virtual void simplify() {}
     virtual void insertRow(int /*row*/) {}
     virtual void insertColumn(int /*column*/) {}
@@ -1583,10 +1575,10 @@ public:
     using QLayoutSupport::findItemAt;
 
 private:
-    virtual void setCurrentCellFromIndicatorOnEmptyCell(int index);
-    virtual void setCurrentCellFromIndicator(Qt::Orientation indicatorOrientation, int index, int increment);
-    virtual bool supportsIndicatorOrientation(Qt::Orientation indicatorOrientation) const;
-    virtual QRect extendedGeometry(int index) const;
+    void setCurrentCellFromIndicatorOnEmptyCell(int index) Q_DECL_OVERRIDE;
+    void setCurrentCellFromIndicator(Qt::Orientation indicatorOrientation, int index, int increment) Q_DECL_OVERRIDE;
+    bool supportsIndicatorOrientation(Qt::Orientation indicatorOrientation) const Q_DECL_OVERRIDE;
+    QRect extendedGeometry(int index) const Q_DECL_OVERRIDE;
 
     const Qt::Orientation m_orientation;
 };
@@ -1707,7 +1699,7 @@ public:
 
     void insertWidget(QWidget *widget, const QPair<int, int> &cell);
     virtual void removeWidget(QWidget *widget) { helper()->removeWidget(layout(), widget); }
-    virtual int findItemAt(int row, int column) const;
+    int findItemAt(int row, int column) const Q_DECL_OVERRIDE;
     using QLayoutSupport::findItemAt;
 
 protected:
@@ -1717,11 +1709,11 @@ protected:
 
 private:
 
-    virtual void setCurrentCellFromIndicatorOnEmptyCell(int index);
-    virtual void setCurrentCellFromIndicator(Qt::Orientation indicatorOrientation, int index, int increment);
+    void setCurrentCellFromIndicatorOnEmptyCell(int index) Q_DECL_OVERRIDE;
+    void setCurrentCellFromIndicator(Qt::Orientation indicatorOrientation, int index, int increment) Q_DECL_OVERRIDE;
     virtual bool supportsIndicatorOrientation(Qt::Orientation) const { return true; }
 
-    virtual QRect extendedGeometry(int index) const;
+    QRect extendedGeometry(int index) const Q_DECL_OVERRIDE;
 
     // Overwrite to check the insertion position (if there are limits)
     virtual void checkCellForInsertion(int * /*row*/, int * /*col*/) const {}
@@ -1820,8 +1812,8 @@ public:
     QGridLayoutSupport(QDesignerFormWindowInterface *formWindow, QWidget *widget, QObject *parent = 0);
 
     virtual void simplify();
-    virtual void insertRow(int row);
-    virtual void insertColumn(int column);
+    void insertRow(int row) Q_DECL_OVERRIDE;
+    void insertColumn(int column) Q_DECL_OVERRIDE;
 
 private:
 };
@@ -1871,7 +1863,7 @@ public:
     virtual void insertColumn(int /*column*/) {}
 
 private:
-    virtual void checkCellForInsertion(int * row, int *col) const;
+    void checkCellForInsertion(int * row, int *col) const Q_DECL_OVERRIDE;
 };
 
 QFormLayoutSupport::QFormLayoutSupport(QDesignerFormWindowInterface *formWindow, QWidget *widget, QObject *parent) :
