@@ -1,40 +1,32 @@
 /****************************************************************************
 **
-** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
-** Contact: http://www.qt-project.org/legal
+** Copyright (C) 2015 The Qt Company Ltd.
+** Contact: http://www.qt.io/licensing/
 **
 ** This file is part of the Qt Designer of the Qt Toolkit.
 **
-** $QT_BEGIN_LICENSE:LGPL$
+** $QT_BEGIN_LICENSE:LGPL21$
 ** Commercial License Usage
 ** Licensees holding valid commercial Qt licenses may use this file in
 ** accordance with the commercial license agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and Digia.  For licensing terms and
-** conditions see http://qt.digia.com/licensing.  For further information
-** use the contact form at http://qt.digia.com/contact-us.
+** a written agreement between you and The Qt Company. For licensing terms
+** and conditions see http://www.qt.io/terms-conditions. For further
+** information use the contact form at http://www.qt.io/contact-us.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 2.1 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU Lesser General Public License version 2.1 requirements
-** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+** General Public License version 2.1 or version 3 as published by the Free
+** Software Foundation and appearing in the file LICENSE.LGPLv21 and
+** LICENSE.LGPLv3 included in the packaging of this file. Please review the
+** following information to ensure the GNU Lesser General Public License
+** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
+** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** In addition, as a special exception, Digia gives you certain additional
-** rights.  These rights are described in the Digia Qt LGPL Exception
+** As a special exception, The Qt Company gives you certain additional
+** rights. These rights are described in The Qt Company LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
-**
-**
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -65,8 +57,8 @@ namespace {
         ReplacementValidator (QObject * parent,
                               const QString &offending,
                               const QString &replacement);
-        virtual void fixup ( QString & input ) const;
-        virtual State validate ( QString & input, int &pos) const;
+        void fixup ( QString & input ) const Q_DECL_OVERRIDE;
+        State validate ( QString & input, int &pos) const Q_DECL_OVERRIDE;
     private:
         const QString m_offending;
         const QString m_replacement;
@@ -94,7 +86,7 @@ namespace {
     class StyleSheetValidator : public ReplacementValidator {
     public:
         StyleSheetValidator (QObject * parent);
-        virtual State validate(QString & input, int &pos) const;
+        State validate(QString & input, int &pos) const Q_DECL_OVERRIDE;
     };
 
     StyleSheetValidator::StyleSheetValidator (QObject * parent) :
@@ -120,8 +112,8 @@ namespace {
     public:
         UrlValidator(QCompleter *completer, QObject *parent);
 
-        virtual State validate(QString &input, int &pos) const;
-        virtual void fixup(QString &input) const;
+        State validate(QString &input, int &pos) const Q_DECL_OVERRIDE;
+        void fixup(QString &input) const Q_DECL_OVERRIDE;
     private:
         QUrl guessUrlFromString(const QString &string) const;
         QCompleter *m_completer;
