@@ -1,40 +1,32 @@
 /****************************************************************************
 **
-** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
-** Contact: http://www.qt-project.org/legal
+** Copyright (C) 2015 The Qt Company Ltd.
+** Contact: http://www.qt.io/licensing/
 **
 ** This file is part of the Qt Linguist of the Qt Toolkit.
 **
-** $QT_BEGIN_LICENSE:LGPL$
+** $QT_BEGIN_LICENSE:LGPL21$
 ** Commercial License Usage
 ** Licensees holding valid commercial Qt licenses may use this file in
 ** accordance with the commercial license agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and Digia.  For licensing terms and
-** conditions see http://qt.digia.com/licensing.  For further information
-** use the contact form at http://qt.digia.com/contact-us.
+** a written agreement between you and The Qt Company. For licensing terms
+** and conditions see http://www.qt.io/terms-conditions. For further
+** information use the contact form at http://www.qt.io/contact-us.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 2.1 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU Lesser General Public License version 2.1 requirements
-** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+** General Public License version 2.1 or version 3 as published by the Free
+** Software Foundation and appearing in the file LICENSE.LGPLv21 and
+** LICENSE.LGPLv3 included in the packaging of this file. Please review the
+** following information to ensure the GNU Lesser General Public License
+** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
+** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** In addition, as a special exception, Digia gives you certain additional
-** rights.  These rights are described in the Digia Qt LGPL Exception
+** As a special exception, The Qt Company gives you certain additional
+** rights. These rights are described in The Qt Company LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
-**
-**
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -266,7 +258,7 @@ bool DataModel::load(const QString &fileName, bool *langGuessed, QWidget *parent
             MessageItem tmp(msg);
             if (msg.type() == TranslatorMessage::Finished)
                 c->incrementFinishedCount();
-            if (msg.type() == TranslatorMessage::Unfinished) {
+            if (msg.type() == TranslatorMessage::Finished || msg.type() == TranslatorMessage::Unfinished) {
                 doCharCounting(tmp.text(), m_srcWords, m_srcChars, m_srcCharsSpc);
                 doCharCounting(tmp.pluralText(), m_srcWords, m_srcChars, m_srcCharsSpc);
                 c->incrementNonobsoleteCount();
@@ -510,7 +502,8 @@ MessageItem *DataModelIterator::current() const
  *****************************************************************************/
 
 MultiMessageItem::MultiMessageItem(const MessageItem *m)
-    : m_text(m->text()),
+    : m_id(m->id()),
+      m_text(m->text()),
       m_pluralText(m->pluralText()),
       m_comment(m->comment()),
       m_nonnullCount(0),
@@ -626,6 +619,16 @@ int MultiContextItem::findMessage(const QString &sourcetext, const QString &comm
     return -1;
 }
 
+int MultiContextItem::findMessageById(const QString &id) const
+{
+    for (int i = 0, cnt = messageCount(); i < cnt; ++i) {
+        MultiMessageItem *m = multiMessageItem(i);
+        if (m->id() == id)
+            return i;
+    }
+    return -1;
+}
+
 /******************************************************************************
  *
  * MultiDataModel
@@ -729,7 +732,14 @@ void MultiDataModel::append(DataModel *dm, bool readWrite)
             QList<MessageItem *> appendItems;
             for (int j = 0; j < c->messageCount(); ++j) {
                 MessageItem *m = c->messageItem(j);
-                int msgIdx = mc->findMessage(m->text(), m->comment());
+
+                int msgIdx = -1;
+                if (!m->id().isEmpty()) // id based translation
+                    msgIdx = mc->findMessageById(m->id());
+
+                if (msgIdx == -1)
+                    msgIdx = mc->findMessage(m->text(), m->comment());
+
                 if (msgIdx >= 0)
                     mc->putMessageItem(msgIdx, m);
                 else
@@ -1229,9 +1239,11 @@ int MessageModel::rowCount(const QModelIndex &parent) const
     return 0;
 }
 
-int MessageModel::columnCount(const QModelIndex &) const
+int MessageModel::columnCount(const QModelIndex &parent) const
 {
-    return m_data->modelCount() + 3;
+    if (!parent.isValid())
+        return m_data->modelCount() + 3;
+    return m_data->modelCount() + 2;
 }
 
 QVariant MessageModel::data(const QModelIndex &index, int role) const
