@@ -1,7 +1,7 @@
 /****************************************************************************
 **
-** Copyright (C) 2014 Digia Plc and/or its subsidiary(-ies).
-** Contact: http://www.qt-project.org/legal
+** Copyright (C) 2015 The Qt Company Ltd.
+** Contact: http://www.qt.io/licensing/
 **
 ** This file is part of the Qt Linguist of the Qt Toolkit.
 **
@@ -10,9 +10,9 @@
 ** Licensees holding valid commercial Qt licenses may use this file in
 ** accordance with the commercial license agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and Digia. For licensing terms and
-** conditions see http://qt.digia.com/licensing. For further information
-** use the contact form at http://qt.digia.com/contact-us.
+** a written agreement between you and The Qt Company. For licensing terms
+** and conditions see http://www.qt.io/terms-conditions. For further
+** information use the contact form at http://www.qt.io/contact-us.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -23,8 +23,8 @@
 ** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
 ** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** In addition, as a special exception, Digia gives you certain additional
-** rights. These rights are described in the Digia Qt LGPL Exception
+** As a special exception, The Qt Company gives you certain additional
+** rights. These rights are described in The Qt Company LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
 ** $QT_END_LICENSE$
@@ -61,6 +61,7 @@ public:
     void setTranslation(const QString &translation)
         { m_message.setTranslation(translation); }
 
+    QString id() const { return m_message.id(); }
     QString context() const { return m_message.context(); }
     QString text() const { return m_message.sourceText(); }
     QString pluralText() const { return m_message.extra(QLatin1String("po-msgid_plural")); }
@@ -263,6 +264,7 @@ struct MultiMessageItem
 {
 public:
     MultiMessageItem(const MessageItem *m);
+    QString id() const { return m_id; }
     QString text() const { return m_text; }
     QString pluralText() const { return m_pluralText; }
     QString comment() const { return m_comment; }
@@ -286,6 +288,7 @@ private:
     void incrementUnfinishedCount() { ++m_unfinishedCount; }
     void decrementUnfinishedCount() { --m_unfinishedCount; }
 
+    QString m_id;
     QString m_text;
     QString m_pluralText;
     QString m_comment;
@@ -307,6 +310,7 @@ public:
     MessageItem *messageItem(int model, int msgIdx) const { return m_messageLists[model][msgIdx]; }
     int firstNonobsoleteMessageIndex(int msgIdx) const;
     int findMessage(const QString &sourcetext, const QString &comment) const;
+    int findMessageById(const QString &id) const;
 
     QString context() const { return m_context; }
     QString comment() const { return m_comment; }
