@@ -1,40 +1,32 @@
 /****************************************************************************
 **
-** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
-** Contact: http://www.qt-project.org/legal
+** Copyright (C) 2015 The Qt Company Ltd.
+** Contact: http://www.qt.io/licensing/
 **
 ** This file is part of the Qt Linguist of the Qt Toolkit.
 **
-** $QT_BEGIN_LICENSE:LGPL$
+** $QT_BEGIN_LICENSE:LGPL21$
 ** Commercial License Usage
 ** Licensees holding valid commercial Qt licenses may use this file in
 ** accordance with the commercial license agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and Digia.  For licensing terms and
-** conditions see http://qt.digia.com/licensing.  For further information
-** use the contact form at http://qt.digia.com/contact-us.
+** a written agreement between you and The Qt Company. For licensing terms
+** and conditions see http://www.qt.io/terms-conditions. For further
+** information use the contact form at http://www.qt.io/contact-us.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 2.1 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU Lesser General Public License version 2.1 requirements
-** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+** General Public License version 2.1 or version 3 as published by the Free
+** Software Foundation and appearing in the file LICENSE.LGPLv21 and
+** LICENSE.LGPLv3 included in the packaging of this file. Please review the
+** following information to ensure the GNU Lesser General Public License
+** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
+** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** In addition, as a special exception, Digia gives you certain additional
-** rights.  These rights are described in the Digia Qt LGPL Exception
+** As a special exception, The Qt Company gives you certain additional
+** rights. These rights are described in The Qt Company LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
-**
-**
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -894,30 +886,9 @@ void QMakeEvaluator::visitProVariable(
         default: // whatever - cannot happen
         case TokAssign:          // =
             zipEmpty(&varVal);
-            if (!m_cumulative) {
-                // FIXME: add check+warning about accidental value removal.
-                // This may be a bit too noisy, though.
-                m_valuemapStack.top()[varName] = varVal;
-            } else {
-                if (!varVal.isEmpty()) {
-                    // We are greedy for values. But avoid exponential growth.
-                    ProStringList &v = valuesRef(varName);
-                    if (v.isEmpty()) {
-                        v = varVal;
-                    } else {
-                        ProStringList old = v;
-                        v = varVal;
-                        QSet<ProString> has;
-                        has.reserve(v.size());
-                        foreach (const ProString &s, v)
-                            has.insert(s);
-                        v.reserve(v.size() + old.size());
-                        foreach (const ProString &s, old)
-                            if (!has.contains(s))
-                                v << s;
-                    }
-                }
-            }
+            // FIXME: add check+warning about accidental value removal.
+            // This may be a bit too noisy, though.
+            m_valuemapStack.top()[varName] = varVal;
             debugMsg(2, "assigning");
             break;
         case TokAppendUnique:    // *=
@@ -933,7 +904,7 @@ void QMakeEvaluator::visitProVariable(
             if (!m_cumulative) {
                 removeEach(&valuesRef(varName), varVal);
             } else {
-                // We are stingy with our values, too.
+                // We are stingy with our values.
             }
             debugMsg(2, "removing");
             break;
@@ -1123,28 +1094,7 @@ bool QMakeEvaluator::prepareProject(const QString &inDir)
     }
   no_cache:
 
-    // Look for mkspecs/ in source and build. First to win determines the root.
-    QString sdir = inDir;
     QString dir = m_outputDir;
-    while (dir != m_buildRoot) {
-        if ((dir != sdir && QFileInfo(sdir, QLatin1String("mkspecs")).isDir())
-                || QFileInfo(dir, QLatin1String("mkspecs")).isDir()) {
-            if (dir != sdir)
-                m_sourceRoot = sdir;
-            m_buildRoot = dir;
-            break;
-        }
-        if (dir == superdir)
-            break;
-        QFileInfo qsdfi(sdir);
-        QFileInfo qdfi(dir);
-        if (qsdfi.isRoot() || qdfi.isRoot())
-            break;
-        sdir = qsdfi.path();
-        dir = qdfi.path();
-    }
-
-    dir = m_outputDir;
     forever {
         QString stashfile = dir + QLatin1String("/.qmake.stash");
         if (dir == (!superdir.isEmpty() ? superdir : m_buildRoot) || m_vfs->exists(stashfile)) {
@@ -1876,14 +1826,12 @@ QMakeEvaluator::VisitReturn QMakeEvaluator::evaluateFile(
         VisitReturn ok = visitProFile(pro, type, flags);
         m_current = m_locationStack.pop();
         pro->deref();
-#ifdef PROEVALUATOR_FULL
         if (ok == ReturnTrue && !(flags & LoadHidden)) {
             ProStringList &iif = m_valuemapStack.first()[ProKey("QMAKE_INTERNAL_INCLUDED_FILES")];
             ProString ifn(fileName);
             if (!iif.contains(ifn))
                 iif << ifn;
         }
-#endif
         return ok;
     } else {
         return ReturnFalse;
@@ -1996,13 +1944,11 @@ QMakeEvaluator::VisitReturn QMakeEvaluator::evaluateFileInto(
     if (ret != ReturnTrue)
         return ret;
     *values = visitor.m_valuemapStack.top();
-#ifdef PROEVALUATOR_FULL
     ProKey qiif("QMAKE_INTERNAL_INCLUDED_FILES");
     ProStringList &iif = m_valuemapStack.first()[qiif];
     foreach (const ProString &ifn, values->value(qiif))
         if (!iif.contains(ifn))
             iif << ifn;
-#endif
     return ReturnTrue;
 }
 
