@@ -1,7 +1,7 @@
 /****************************************************************************
 **
-** Copyright (C) 2014 Digia Plc and/or its subsidiary(-ies).
-** Contact: http://www.qt-project.org/legal
+** Copyright (C) 2015 The Qt Company Ltd.
+** Contact: http://www.qt.io/licensing/
 **
 ** This file is part of the Qt Linguist of the Qt Toolkit.
 **
@@ -10,9 +10,9 @@
 ** Licensees holding valid commercial Qt licenses may use this file in
 ** accordance with the commercial license agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and Digia. For licensing terms and
-** conditions see http://qt.digia.com/licensing. For further information
-** use the contact form at http://qt.digia.com/contact-us.
+** a written agreement between you and The Qt Company. For licensing terms
+** and conditions see http://www.qt.io/terms-conditions. For further
+** information use the contact form at http://www.qt.io/contact-us.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -23,8 +23,8 @@
 ** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
 ** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** In addition, as a special exception, Digia gives you certain additional
-** rights. These rights are described in the Digia Qt LGPL Exception
+** As a special exception, The Qt Company gives you certain additional
+** rights. These rights are described in The Qt Company LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
 ** $QT_END_LICENSE$
@@ -151,7 +151,9 @@ void Translator::extend(const TranslatorMessage &msg, ConversionData &cd)
     } else {
         TranslatorMessage &emsg = m_messages[index];
         if (emsg.sourceText().isEmpty()) {
+            delIndex(index);
             emsg.setSourceText(msg.sourceText());
+            addIndex(index, msg);
         } else if (!msg.sourceText().isEmpty() && emsg.sourceText() != msg.sourceText()) {
             cd.appendError(QString::fromLatin1("Contradicting source strings for message with id '%1'.")
                            .arg(emsg.id()));
@@ -185,7 +187,12 @@ void Translator::extend(const TranslatorMessage &msg, ConversionData &cd)
 
 void Translator::insert(int idx, const TranslatorMessage &msg)
 {
-    addIndex(idx, msg);
+    if (m_indexOk) {
+        if (idx == m_messages.count())
+            addIndex(idx, msg);
+        else
+            m_indexOk = false;
+    }
     m_messages.insert(idx, msg);
 }
 
