@@ -1,7 +1,7 @@
 /****************************************************************************
 **
-** Copyright (C) 2014 Digia Plc and/or its subsidiary(-ies).
-** Contact: http://www.qt-project.org/legal
+** Copyright (C) 2015 The Qt Company Ltd.
+** Contact: http://www.qt.io/licensing/
 **
 ** This file is part of the tools applications of the Qt Toolkit.
 **
@@ -10,9 +10,9 @@
 ** Licensees holding valid commercial Qt licenses may use this file in
 ** accordance with the commercial license agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and Digia. For licensing terms and
-** conditions see http://qt.digia.com/licensing. For further information
-** use the contact form at http://qt.digia.com/contact-us.
+** a written agreement between you and The Qt Company. For licensing terms
+** and conditions see http://www.qt.io/terms-conditions. For further
+** information use the contact form at http://www.qt.io/contact-us.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -23,8 +23,8 @@
 ** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
 ** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** In addition, as a special exception, Digia gives you certain additional
-** rights. These rights are described in the Digia Qt LGPL Exception
+** As a special exception, The Qt Company gives you certain additional
+** rights. These rights are described in The Qt Company LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
 ** $QT_END_LICENSE$
@@ -43,6 +43,7 @@
 #  include <QtGui/QOpenGLFunctions>
 #endif // QT_NO_OPENGL
 #include <QtGui/QWindow>
+#include <QtGui/QTouchDevice>
 
 #ifdef NETWORK_DIAG
 #  include <QSslSocket>
@@ -57,6 +58,7 @@
 #include <QtCore/QStandardPaths>
 #include <QtCore/QDir>
 #include <QtCore/QFileSelector>
+#include <QtCore/QDebug>
 
 #include <private/qsimd_p.h>
 #include <private/qguiapplication_p.h>
@@ -202,6 +204,14 @@ static void dumpStandardLocation(QTextStream &str, QStandardPaths::StandardLocat
 #define DUMP_LIBRARYPATH(str, loc) \
     str << "  " << #loc << ": " << QDir::toNativeSeparators(QLibraryInfo::location(QLibraryInfo::loc)) << '\n';
 
+// Helper to format a type via QDebug to be used for QFlags/Q_ENUM.
+template <class T>
+static QString formatQDebug(T t)
+{
+    QString result;
+    QDebug(&result) << t;
+    return result;
+}
 
 QString qtDiag(unsigned flags)
 {
@@ -215,6 +225,7 @@ QString qtDiag(unsigned flags)
               << " [" << QSysInfo::kernelType() << " version " << QSysInfo::kernelVersion() << "]\n";
 
     str << "\nArchitecture: " << QSysInfo::currentCpuArchitecture() << "; features:";
+#if defined(Q_PROCESSOR_X86)
     DUMP_CPU_FEATURE(SSE2, "SSE2");
     DUMP_CPU_FEATURE(SSE3, "SSE3");
     DUMP_CPU_FEATURE(SSSE3, "SSSE3");
@@ -224,7 +235,12 @@ QString qtDiag(unsigned flags)
     DUMP_CPU_FEATURE(AVX2, "AVX2");
     DUMP_CPU_FEATURE(RTM, "RTM");
     DUMP_CPU_FEATURE(HLE, "HLE");
+#elif defined(Q_PROCESSOR_ARM)
     DUMP_CPU_FEATURE(ARM_NEON, "Neon");
+#elif defined(Q_PROCESSOR_MIPS)
+    DUMP_CPU_FEATURE(DSP, "DSP");
+    DUMP_CPU_FEATURE(DSPR2, "DSPR2");
+#endif
     str << '\n';
 
     str << "\nLibrary info:\n";
@@ -242,6 +258,7 @@ QString qtDiag(unsigned flags)
     DUMP_LIBRARYPATH(str, TranslationsPath)
     DUMP_LIBRARYPATH(str, ExamplesPath)
     DUMP_LIBRARYPATH(str, TestsPath)
+    DUMP_LIBRARYPATH(str, SettingsPath)
 
     str << "\nStandard paths [*...* denote writable entry]:\n";
     DUMP_STANDARDPATH(str, DesktopLocation)
@@ -253,7 +270,7 @@ QString qtDiag(unsigned flags)
     DUMP_STANDARDPATH(str, PicturesLocation)
     DUMP_STANDARDPATH(str, TempLocation)
     DUMP_STANDARDPATH(str, HomeLocation)
-    DUMP_STANDARDPATH(str, DataLocation)
+    DUMP_STANDARDPATH(str, AppLocalDataLocation)
     DUMP_STANDARDPATH(str, CacheLocation)
     DUMP_STANDARDPATH(str, GenericDataLocation)
     DUMP_STANDARDPATH(str, RuntimeLocation)
@@ -261,6 +278,8 @@ QString qtDiag(unsigned flags)
     DUMP_STANDARDPATH(str, DownloadLocation)
     DUMP_STANDARDPATH(str, GenericCacheLocation)
     DUMP_STANDARDPATH(str, GenericConfigLocation)
+    DUMP_STANDARDPATH(str, AppDataLocation)
+    DUMP_STANDARDPATH(str, AppConfigLocation)
 
     str << "\nFile selectors (increasing order of precedence):\n ";
     foreach (const QString &s, QFileSelector().allSelectors())
@@ -298,6 +317,7 @@ QString qtDiag(unsigned flags)
     DUMP_CAPABILITY(str, platformIntegration, SyncState)
     DUMP_CAPABILITY(str, platformIntegration, RasterGLSurface)
     DUMP_CAPABILITY(str, platformIntegration, AllGLFunctionsQueryable)
+    DUMP_CAPABILITY(str, platformIntegration, ApplicationIcon)
     str << '\n';
 
     const QStyleHints *styleHints = QGuiApplication::styleHints();
@@ -320,7 +340,14 @@ QString qtDiag(unsigned flags)
     str << '\n'
         << "  fontSmoothingGamma: " << styleHints->fontSmoothingGamma() << '\n'
         << "  useRtlExtensions: " << styleHints->useRtlExtensions() << '\n'
-        << "  setFocusOnTouchRelease: " << styleHints->setFocusOnTouchRelease() << '\n';
+        << "  setFocusOnTouchRelease: " << styleHints->setFocusOnTouchRelease() << '\n'
+        << "  tabFocusBehavior: " << formatQDebug(styleHints->tabFocusBehavior()) << '\n'
+        << "  singleClickActivation: " << styleHints->singleClickActivation() << '\n';
+    str << "\nAdditional style hints (QPlatformIntegration):\n"
+        << "  ShowIsMaximized: "
+        << platformIntegration->styleHint(QPlatformIntegration::ShowIsMaximized).toBool() << '\n'
+        << "  ReplayMousePressOutsidePopup: "
+        << platformIntegration->styleHint(QPlatformIntegration::ReplayMousePressOutsidePopup).toBool() << '\n';
 
     const QPlatformTheme *platformTheme = QGuiApplicationPrivate::platformTheme();
     str << "\nTheme:\n  Styles: " << platformTheme->themeHint(QPlatformTheme::StyleNames).toStringList();
@@ -371,6 +398,33 @@ QString qtDiag(unsigned flags)
             << "\n\n";
     }
 
+    const QList<const QTouchDevice *> touchDevices = QTouchDevice::devices();
+    if (!touchDevices.isEmpty()) {
+        str << "Touch devices: " << touchDevices.size() << '\n';
+        foreach (const QTouchDevice *device, touchDevices) {
+            str << "  " << (device->type() == QTouchDevice::TouchScreen ? "TouchScreen" : "TouchPad")
+                << " \"" << device->name() << "\", max " << device->maximumTouchPoints()
+                << " touch points, capabilities:";
+            const QTouchDevice::Capabilities capabilities = device->capabilities();
+            if (capabilities & QTouchDevice::Position)
+                str << " Position";
+            if (capabilities & QTouchDevice::Area)
+                str << " Area";
+            if (capabilities & QTouchDevice::Pressure)
+                str << " Pressure";
+            if (capabilities & QTouchDevice::Velocity)
+                str << " Velocity";
+            if (capabilities & QTouchDevice::RawPositions)
+                str << " RawPositions";
+            if (capabilities & QTouchDevice::NormalizedPosition)
+                str << " NormalizedPosition";
+            if (capabilities & QTouchDevice::MouseEmulation)
+                str << " MouseEmulation";
+            str << '\n';
+        }
+        str << "\n\n";
+    }
+
 #ifndef QT_NO_OPENGL
     dumpGlInfo(str, flags & QtDiagGlExtensions);
     str << "\n\n";
