@@ -1,40 +1,32 @@
 /****************************************************************************
 **
-** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
-** Contact: http://www.qt-project.org/legal
+** Copyright (C) 2015 The Qt Company Ltd.
+** Contact: http://www.qt.io/licensing/
 **
 ** This file is part of the tools applications of the Qt Toolkit.
 **
-** $QT_BEGIN_LICENSE:LGPL$
+** $QT_BEGIN_LICENSE:LGPL21$
 ** Commercial License Usage
 ** Licensees holding valid commercial Qt licenses may use this file in
 ** accordance with the commercial license agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and Digia.  For licensing terms and
-** conditions see http://qt.digia.com/licensing.  For further information
-** use the contact form at http://qt.digia.com/contact-us.
+** a written agreement between you and The Qt Company. For licensing terms
+** and conditions see http://www.qt.io/terms-conditions. For further
+** information use the contact form at http://www.qt.io/contact-us.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 2.1 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU Lesser General Public License version 2.1 requirements
-** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+** General Public License version 2.1 or version 3 as published by the Free
+** Software Foundation and appearing in the file LICENSE.LGPLv21 and
+** LICENSE.LGPLv3 included in the packaging of this file. Please review the
+** following information to ensure the GNU Lesser General Public License
+** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
+** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** In addition, as a special exception, Digia gives you certain additional
-** rights.  These rights are described in the Digia Qt LGPL Exception
+** As a special exception, The Qt Company gives you certain additional
+** rights. These rights are described in The Qt Company LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
-**
-**
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -862,13 +854,13 @@ void QtGradientEditor::setGradient(const QGradient &grad)
     d_ptr->m_spreadGroup->button(idx)->setChecked(true);
 
     if (type == QGradient::LinearGradient) {
-        QLinearGradient *gr = (QLinearGradient *)(&grad);
+        const QLinearGradient *gr = static_cast<const QLinearGradient *>(&grad);
         d_ptr->setStartLinear(gr->start());
         d_ptr->setEndLinear(gr->finalStop());
         d_ptr->m_ui.gradientWidget->setStartLinear(gr->start());
         d_ptr->m_ui.gradientWidget->setEndLinear(gr->finalStop());
     } else if (type == QGradient::RadialGradient) {
-        QRadialGradient *gr = (QRadialGradient *)(&grad);
+        const QRadialGradient *gr = static_cast<const QRadialGradient *>(&grad);
         d_ptr->setCentralRadial(gr->center());
         d_ptr->setFocalRadial(gr->focalPoint());
         d_ptr->setRadiusRadial(gr->radius());
@@ -876,7 +868,7 @@ void QtGradientEditor::setGradient(const QGradient &grad)
         d_ptr->m_ui.gradientWidget->setFocalRadial(gr->focalPoint());
         d_ptr->m_ui.gradientWidget->setRadiusRadial(gr->radius());
     } else if (type == QGradient::ConicalGradient) {
-        QConicalGradient *gr = (QConicalGradient *)(&grad);
+        const QConicalGradient *gr = static_cast<const QConicalGradient *>(&grad);
         d_ptr->setCentralConical(gr->center());
         d_ptr->setAngleConical(gr->angle());
         d_ptr->m_ui.gradientWidget->setCentralConical(gr->center());
