@@ -1,7 +1,7 @@
 /****************************************************************************
 **
-** Copyright (C) 2014 Digia Plc and/or its subsidiary(-ies).
-** Contact: http://www.qt-project.org/legal
+** Copyright (C) 2015 The Qt Company Ltd.
+** Contact: http://www.qt.io/licensing/
 **
 ** This file is part of the tools applications of the Qt Toolkit.
 **
@@ -10,9 +10,9 @@
 ** Licensees holding valid commercial Qt licenses may use this file in
 ** accordance with the commercial license agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and Digia. For licensing terms and
-** conditions see http://qt.digia.com/licensing. For further information
-** use the contact form at http://qt.digia.com/contact-us.
+** a written agreement between you and The Qt Company. For licensing terms
+** and conditions see http://www.qt.io/terms-conditions. For further
+** information use the contact form at http://www.qt.io/contact-us.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -23,8 +23,8 @@
 ** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
 ** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** In addition, as a special exception, Digia gives you certain additional
-** rights. These rights are described in the Digia Qt LGPL Exception
+** As a special exception, The Qt Company gives you certain additional
+** rights. These rights are described in The Qt Company LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
 ** $QT_END_LICENSE$
@@ -54,47 +54,54 @@ enum QtModule
     : quint64
 #endif
 {
-    QtBluetoothModule = 0x1,
-    QtCLuceneModule = 0x2,
-    QtConcurrentModule = 0x4,
-    QtCoreModule = 0x8,
-    QtDeclarativeModule = 0x10,
-    QtDesignerComponents = 0x20,
-    QtDesignerModule = 0x40,
-    QtGuiModule = 0x80,
-    QtCluceneModule = 0x100,
-    QtHelpModule = 0x200,
-    QtMultimediaModule = 0x400,
-    QtMultimediaWidgetsModule = 0x800,
-    QtMultimediaQuickModule = 0x1000,
-    QtNetworkModule = 0x2000,
-    QtNfcModule = 0x4000,
-    QtOpenGLModule = 0x8000,
-    QtPositioningModule = 0x10000,
-    QtPrintSupportModule = 0x20000,
-    QtQmlModule = 0x40000,
-    QtQuickModule = 0x80000,
-    QtQuickParticlesModule = 0x100000,
-    QtScriptModule = 0x200000,
-    QtScriptToolsModule = 0x400000,
-    QtSensorsModule = 0x800000,
-    QtSerialPortModule = 0x1000000,
-    QtSqlModule = 0x2000000,
-    QtSvgModule = 0x4000000,
-    QtTestModule = 0x8000000,
-    QtWidgetsModule = 0x10000000,
-    QtWinExtrasModule = 0x20000000,
-    QtXmlModule = 0x40000000,
-    QtXmlPatternsModule = 0x80000000,
-    QtWebKitModule = 0x100000000,
-    QtWebKitWidgetsModule = 0x200000000,
-    QtQuickWidgetsModule = 0x400000000,
-    QtWebSocketsModule = 0x800000000,
-    QtEnginioModule = 0x1000000000,
-    QtWebEngineCoreModule = 0x2000000000,
-    QtWebEngineModule = 0x4000000000,
-    QtWebEngineWidgetsModule = 0x8000000000,
-    QtQmlToolingModule = 0x10000000000
+    QtBluetoothModule         = 0x000000000001,
+    QtCLuceneModule           = 0x000000000002,
+    QtConcurrentModule        = 0x000000000004,
+    QtCoreModule              = 0x000000000008,
+    QtDeclarativeModule       = 0x000000000010,
+    QtDesignerComponents      = 0x000000000020,
+    QtDesignerModule          = 0x000000000040,
+    QtGuiModule               = 0x000000000080,
+    QtCluceneModule           = 0x000000000100,
+    QtHelpModule              = 0x000000000200,
+    QtMultimediaModule        = 0x000000000400,
+    QtMultimediaWidgetsModule = 0x000000000800,
+    QtMultimediaQuickModule   = 0x000000001000,
+    QtNetworkModule           = 0x000000002000,
+    QtNfcModule               = 0x000000004000,
+    QtOpenGLModule            = 0x000000008000,
+    QtPositioningModule       = 0x000000010000,
+    QtPrintSupportModule      = 0x000000020000,
+    QtQmlModule               = 0x000000040000,
+    QtQuickModule             = 0x000000080000,
+    QtQuickParticlesModule    = 0x000000100000,
+    QtScriptModule            = 0x000000200000,
+    QtScriptToolsModule       = 0x000000400000,
+    QtSensorsModule           = 0x000000800000,
+    QtSerialPortModule        = 0x000001000000,
+    QtSqlModule               = 0x000002000000,
+    QtSvgModule               = 0x000004000000,
+    QtTestModule              = 0x000008000000,
+    QtWidgetsModule           = 0x000010000000,
+    QtWinExtrasModule         = 0x000020000000,
+    QtXmlModule               = 0x000040000000,
+    QtXmlPatternsModule       = 0x000080000000,
+    QtWebKitModule            = 0x000100000000,
+    QtWebKitWidgetsModule     = 0x000200000000,
+    QtQuickWidgetsModule      = 0x000400000000,
+    QtWebSocketsModule        = 0x000800000000,
+    QtEnginioModule           = 0x001000000000,
+    QtWebEngineCoreModule     = 0x002000000000,
+    QtWebEngineModule         = 0x004000000000,
+    QtWebEngineWidgetsModule  = 0x008000000000,
+    QtQmlToolingModule        = 0x010000000000,
+    Qt3DCoreModule            = 0x020000000000,
+    Qt3DRendererModule        = 0x040000000000,
+    Qt3DQuickModule           = 0x080000000000,
+    Qt3DQuickRendererModule   = 0x100000000000,
+    Qt3DInputModule           = 0x200000000000,
+    QtLocationModule          = 0x400000000000,
+    QtWebChannelModule        = 0x800000000000
 };
 
 struct QtModuleEntry {
@@ -144,7 +151,14 @@ QtModuleEntry qtModuleEntries[] = {
     { QtXmlPatternsModule, "xmlpatterns", "Qt5XmlPatterns", "qtxmlpatterns" },
     { QtWebEngineCoreModule, "webenginecore", "Qt5WebEngineCore", 0 },
     { QtWebEngineModule, "webengine", "Qt5WebEngine", 0 },
-    { QtWebEngineWidgetsModule, "webenginewidgets", "Qt5WebEngineWidgets", 0 }
+    { QtWebEngineWidgetsModule, "webenginewidgets", "Qt5WebEngineWidgets", 0 },
+    { Qt3DCoreModule, "3dcore", "Qt53DCore", 0 },
+    { Qt3DRendererModule, "3drenderer", "Qt53DRenderer", 0 },
+    { Qt3DQuickModule, "3dquick", "Qt53DQuick", 0 },
+    { Qt3DQuickRendererModule, "3dquickrenderer", "Qt53DQuickRenderer", 0 },
+    { Qt3DInputModule, "3dinput", "Qt53DInput", 0 },
+    { QtLocationModule, "geoservices", "Qt5Location", 0 },
+    { QtWebChannelModule, "webchannel", "Qt5WebChannel", 0 }
 };
 
 static const char webKitProcessC[] = "QtWebProcess";
@@ -184,6 +198,12 @@ static Platform platformFromMkSpec(const QString &xSpec)
         return WinPhoneIntel;
     if (xSpec.startsWith(QLatin1String("winphone-arm")))
         return WinPhoneArm;
+    if (xSpec.startsWith(QLatin1String("wince"))) {
+        if (xSpec.contains(QLatin1String("-x86-")))
+            return WinCEIntel;
+        if (xSpec.contains(QLatin1String("-arm")))
+            return WinCEArm;
+    }
     return UnknownPlatform;
 }
 
@@ -245,12 +265,18 @@ struct Options {
     quint64 updateFileFlags;
     QStringList qmlDirectories; // Project's QML files.
     QString directory;
+    QString translationsDirectory; // Translations target directory
     QString libraryDirectory;
     QStringList binaries;
     JsonOutput *json;
     ListOption list;
     DebugDetection debugDetection;
     bool debugMatchAll;
+
+    inline bool isWinRtOrWinPhone() const {
+        return (platform == WinPhoneArm || platform == WinPhoneIntel
+                || platform == WinRtArm || platform == WinRtIntel);
+    }
 };
 
 // Return binary from folder
@@ -577,6 +603,7 @@ static inline int parseArguments(const QStringList &arguments, QCommandLineParse
             options->binaries.append(path);
         }
     }
+    options->translationsDirectory = options->directory + QLatin1String("/translations");
     return 0;
 }
 
@@ -701,7 +728,8 @@ private:
 static inline quint64 qtModuleForPlugin(const QString &subDirName)
 {
     if (subDirName == QLatin1String("accessible") || subDirName == QLatin1String("iconengines")
-        || subDirName == QLatin1String("imageformats") || subDirName == QLatin1String("platforms")) {
+        || subDirName == QLatin1String("imageformats") || subDirName == QLatin1String("platforms")
+        || subDirName == QLatin1String("platforminputcontexts")) {
         return QtGuiModule;
     }
     if (subDirName == QLatin1String("bearer"))
@@ -720,10 +748,14 @@ static inline quint64 qtModuleForPlugin(const QString &subDirName)
         return QtDeclarativeModule;
     if (subDirName == QLatin1String("position"))
         return QtPositioningModule;
+    if (subDirName == QLatin1String("geoservices"))
+        return QtLocationModule;
     if (subDirName == QLatin1String("sensors") || subDirName == QLatin1String("sensorgestures"))
         return QtSensorsModule;
     if (subDirName == QLatin1String("qtwebengine"))
         return QtWebEngineModule | QtWebEngineCoreModule | QtWebEngineWidgetsModule;
+    if (subDirName == QLatin1String("sceneparsers"))
+        return Qt3DRendererModule;
     return 0; // "designer"
 }
 
@@ -744,7 +776,7 @@ static quint64 qtModule(const QString &module)
 
 QStringList findQtPlugins(quint64 *usedQtModules, quint64 disabledQtModules,
                           const QString &qtPluginsDirName, const QString &libraryLocation,
-                          DebugMatchMode debugMatchMode, Platform platform, QString *platformPlugin)
+                          DebugMatchMode debugMatchModeIn, Platform platform, QString *platformPlugin)
 {
     QString errorMessage;
     if (qtPluginsDirName.isEmpty())
@@ -754,6 +786,9 @@ QStringList findQtPlugins(quint64 *usedQtModules, quint64 disabledQtModules,
     foreach (const QString &subDirName, pluginsDir.entryList(QStringList(QLatin1String("*")), QDir::Dirs | QDir::NoDotAndDotDot)) {
         const quint64 module = qtModuleForPlugin(subDirName);
         if (module & *usedQtModules) {
+            const DebugMatchMode debugMatchMode = (module & QtWebEngineCoreModule)
+                ? MatchDebugOrRelease // QTBUG-44331: Debug detection does not work for webengine, deploy all.
+                : debugMatchModeIn;
             const QString subDirPath = qtPluginsDirName + QLatin1Char('/') + subDirName;
             QDir subDir(subDirPath);
             // Filter out disabled plugins
@@ -766,6 +801,8 @@ QStringList findQtPlugins(quint64 *usedQtModules, quint64 disabledQtModules,
                 switch (platform) {
                 case Windows:
                 case WindowsMinGW:
+                case WinCEIntel:
+                case WinCEArm:
                     filter = QStringLiteral("qwindows");
                     break;
                 case WinRtIntel:
@@ -897,15 +934,17 @@ static QString libraryPath(const QString &libraryLocation, const char *name,
     return result;
 }
 
-static QStringList compilerRunTimeLibs(Platform platform, unsigned wordSize)
+static QStringList compilerRunTimeLibs(Platform platform, bool isDebug, unsigned wordSize)
 {
     QStringList result;
     switch (platform) {
     case WindowsMinGW: { // MinGW: Add runtime libraries
         static const char *minGwRuntimes[] = {"*gcc_", "*stdc++", "*winpthread"};
         const QString gcc = findInPath(QStringLiteral("g++.exe"));
-        if (gcc.isEmpty())
+        if (gcc.isEmpty()) {
+            std::wcerr << "Warning: Cannot find GCC installation directory. g++.exe must be in the path.\n";
             break;
+        }
         const QString binPath = QFileInfo(gcc).absolutePath();
         QDir dir(binPath);
         QStringList filters;
@@ -934,21 +973,33 @@ static QStringList compilerRunTimeLibs(Platform platform, unsigned wordSize)
                        << QDir::toNativeSeparators(vcRedistDirName).toStdWString() << ".\n";
             break;
         }
-        const QStringList countryCodes = vcRedistDir.entryList(QStringList(QStringLiteral("[0-9]*")), QDir::Dirs);
-        QString redist;
-        if (!countryCodes.isEmpty()) {
-            const QFileInfo fi(vcRedistDirName + slash + countryCodes.first() + slash
-                               + QStringLiteral("vcredist_x") + QLatin1String(wordSize > 32 ? "64" : "86")
-                               + QStringLiteral(".exe"));
-            if (fi.isFile())
-                redist = fi.absoluteFilePath();
+        QStringList redistFiles;
+        const QString wordSizeString(QLatin1String(wordSize > 32 ? "x64" : "x86"));
+        if (isDebug) {
+            // Append DLLs from Debug_NonRedist\x??\Microsoft.VC<version>.DebugCRT.
+            if (vcRedistDir.cd(QLatin1String("Debug_NonRedist")) && vcRedistDir.cd(wordSizeString)) {
+                const QStringList names = vcRedistDir.entryList(QStringList(QStringLiteral("Microsoft.VC*.DebugCRT")), QDir::Dirs);
+                if (!names.isEmpty() && vcRedistDir.cd(names.first())) {
+                    foreach (const QFileInfo &dll, vcRedistDir.entryInfoList(QStringList(QLatin1String("*.dll"))))
+                        redistFiles.append(dll.absoluteFilePath());
+                }
+            }
+        } else { // release: Bundle vcredist<>.exe
+            const QStringList countryCodes = vcRedistDir.entryList(QStringList(QStringLiteral("[0-9]*")), QDir::Dirs);
+            if (!countryCodes.isEmpty()) {
+                const QFileInfo fi(vcRedistDirName + slash + countryCodes.first() + slash
+                                   + QStringLiteral("vcredist_") + wordSizeString
+                                   + QStringLiteral(".exe"));
+                if (fi.isFile())
+                    redistFiles.append(fi.absoluteFilePath());
+            }
         }
-        if (redist.isEmpty()) {
-            std::wcerr << "Warning: Cannot find Visual Studio redistributable in "
-                       << QDir::toNativeSeparators(vcRedistDirName).toStdWString() << ".\n";
+        if (redistFiles.isEmpty()) {
+            std::wcerr << "Warning: Cannot find Visual Studio " << (isDebug ? "debug" : "release")
+                       << " redistributable files in " << QDir::toNativeSeparators(vcRedistDirName).toStdWString() << ".\n";
             break;
         }
-        result.append(redist);
+        result.append(redistFiles);
     }
     default:
         break;
@@ -1022,7 +1073,7 @@ static DeployResult deploy(const Options &options,
     }
 
     const bool usesQml2 = !(options.disabledLibraries & QtQmlModule)
-                            && ((result.directlyUsedQtLibraries & (QtQmlModule | QtQuickModule))
+        && ((result.directlyUsedQtLibraries & (QtQmlModule | QtQuickModule | Qt3DQuickModule))
                                 || (options.additionalLibraries & QtQmlModule));
 
     if (optVerboseLevel) {
@@ -1039,11 +1090,13 @@ static DeployResult deploy(const Options &options,
         return result;
     }
 
-    // Some Windows-specific checks in QtCore: ICU
+    // Some Windows-specific checks: Qt5Core depends on ICU when configured with "-icu". Other than
+    // that, Qt5WebKit has a hard dependency on ICU.
     if (options.platform & WindowsBased)  {
-        const QStringList qt5Core = dependentQtLibs.filter(QStringLiteral("Qt5Core"), Qt::CaseInsensitive);
-        if (!qt5Core.isEmpty()) {
-            QStringList icuLibs = findDependentLibraries(qt5Core.front(), options.platform, errorMessage).filter(QStringLiteral("ICU"), Qt::CaseInsensitive);
+        const QStringList qtLibs = dependentQtLibs.filter(QStringLiteral("Qt5Core"), Qt::CaseInsensitive)
+            + dependentQtLibs.filter(QStringLiteral("Qt5WebKit"), Qt::CaseInsensitive);
+        foreach (const QString &qtLib, qtLibs) {
+            QStringList icuLibs = findDependentLibraries(qtLib, options.platform, errorMessage).filter(QStringLiteral("ICU"), Qt::CaseInsensitive);
             if (!icuLibs.isEmpty()) {
                 // Find out the ICU version to add the data library icudtXX.dll, which does not show
                 // as a dependency.
@@ -1064,8 +1117,9 @@ static DeployResult deploy(const Options &options,
                     }
                     dependentQtLibs.push_back(icuPath);
                 } // foreach icuLib
+                break;
             } // !icuLibs.isEmpty()
-        } // Qt5Core
+        } // Qt5Core/Qt5WebKit
     } // Windows
 
     // Scan Quick2 imports
@@ -1152,7 +1206,8 @@ static DeployResult deploy(const Options &options,
     }
 
     // Check for ANGLE on the Qt5Gui library.
-    if ((options.platform & WindowsBased) && !qtGuiLibrary.isEmpty())  {
+    if ((options.platform & WindowsBased) && options.platform != WinCEIntel
+        && options.platform != WinCEArm && !qtGuiLibrary.isEmpty())  {
         QString libGlesName = QStringLiteral("libGLESV2");
         if (isDebug)
             libGlesName += QLatin1Char('d');
@@ -1170,8 +1225,7 @@ static DeployResult deploy(const Options &options,
             libEglFullPath += QLatin1String(windowsSharedLibrarySuffix);
             deployedQtLibraries.append(libEglFullPath);
             // Find the system D3d Compiler matching the D3D library.
-            if (options.systemD3dCompiler && options.platform != WinPhoneArm && options.platform != WinPhoneIntel
-                    && options.platform != WinRtArm && options.platform != WinRtIntel) {
+            if (options.systemD3dCompiler && !options.isWinRtOrWinPhone()) {
                 const QString d3dCompiler = findD3dCompiler(options.platform, qtBinDir, wordSize);
                 if (d3dCompiler.isEmpty()) {
                     std::wcerr << "Warning: Cannot find any version of the d3dcompiler DLL.\n";
@@ -1193,11 +1247,19 @@ static DeployResult deploy(const Options &options,
             options.directory : options.libraryDirectory;
         QStringList libraries = deployedQtLibraries;
         if (options.compilerRunTime)
-            libraries.append(compilerRunTimeLibs(options.platform, wordSize));
+            libraries.append(compilerRunTimeLibs(options.platform, isDebug, wordSize));
         foreach (const QString &qtLib, libraries) {
             if (!updateFile(qtLib, targetPath, options.updateFileFlags, options.json, errorMessage))
                 return result;
         }
+
+        if (!options.isWinRtOrWinPhone()) {
+            const QString qt5CoreName = QFileInfo(libraryPath(libraryLocation, "Qt5Core", qtLibInfix,
+                                                              options.platform, isDebug)).fileName();
+
+            if (!patchQtCore(targetPath + QLatin1Char('/') + qt5CoreName, errorMessage))
+                return result;
+        }
     } // optLibraries
 
     // Update plugins
@@ -1259,11 +1321,13 @@ static DeployResult deploy(const Options &options,
         } // Quick 1
     } // optQuickImports
 
-    if (options.translations
-        && !deployTranslations(qmakeVariables.value(QStringLiteral("QT_INSTALL_TRANSLATIONS")),
-                               result.deployedQtLibraries, options.directory,
-                               options.updateFileFlags, errorMessage)) {
-        return result;
+    if (options.translations) {
+        if (!createDirectory(options.translationsDirectory, errorMessage)
+            || !deployTranslations(qmakeVariables.value(QStringLiteral("QT_INSTALL_TRANSLATIONS")),
+                                   result.deployedQtLibraries, options.translationsDirectory,
+                                   options.updateFileFlags, errorMessage)) {
+            return result;
+        }
     }
 
     result.success = true;
@@ -1290,7 +1354,10 @@ static bool deployWebProcess(const QMap<QString, QString> &qmakeVariables,
 static bool deployWebEngine(const QMap<QString, QString> &qmakeVariables,
                              const Options &options, QString *errorMessage)
 {
-    static const char *installDataFiles[] = {"icudtl.dat", "qtwebengine_resources.pak"};
+    static const char *installDataFiles[] = {"icudtl.dat",
+                                             "qtwebengine_resources.pak",
+                                             "qtwebengine_resources_100p.pak",
+                                             "qtwebengine_resources_200p.pak"};
 
     std::wcout << "Deploying: " << webEngineProcessC << "...\n";
     if (!deployWebProcess(qmakeVariables, webEngineProcessC, options, errorMessage)) {
@@ -1314,7 +1381,8 @@ static bool deployWebEngine(const QMap<QString, QString> &qmakeVariables,
         return true;
     }
     // Missing translations may cause crashes, ignore --no-translations.
-    return updateFile(translations.absoluteFilePath(), options.directory,
+    return createDirectory(options.translationsDirectory, errorMessage)
+        && updateFile(translations.absoluteFilePath(), options.translationsDirectory,
                       options.updateFileFlags, options.json, errorMessage);
 }
 
@@ -1323,6 +1391,14 @@ int main(int argc, char **argv)
     QCoreApplication a(argc, argv);
     QCoreApplication::setApplicationVersion(QLatin1String(QT_VERSION_STR));
 
+    const QByteArray qtBinPath = QFile::encodeName(QDir::toNativeSeparators(QCoreApplication::applicationDirPath()));
+    QByteArray path = qgetenv("PATH");
+    if (!path.contains(qtBinPath)) { // QTBUG-39177, ensure Qt is in the path so that qt.conf is taken into account.
+        path += ';';
+        path += qtBinPath;
+        qputenv("PATH", path);
+    }
+
     Options options;
     QString errorMessage;
     const QMap<QString, QString> qmakeVariables = queryQMakeAll(&errorMessage);
